import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:yflutter_widgets/application.dart';
import 'package:yflutter_widgets/widgets/ycustom_card.dart';
import 'package:yflutter_widgets/widgets/ydashed_line.dart';
import 'package:yflutter_widgets/widgets/ydivide.dart';
import 'package:flutter/material.dart';

import 'router/routes_mapping.dart';

void main() {
  runApp(MyApp());
}

class MyApp extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    Routes.routesConfiguration(Application.router);
    return MaterialApp(
        debugShowCheckedModeBanner: false,
        theme: ThemeData(
          platform: TargetPlatform.iOS,
            visualDensity: VisualDensity.adaptivePlatformDensity,
            pageTransitionsTheme: PageTransitionsTheme(builders: {
              TargetPlatform.android: CupertinoPageTransitionsBuilder(),
              TargetPlatform.iOS: CupertinoPageTransitionsBuilder(),
            })
        ),
        home: YHomePage(),
    );
  }
}

class YHomePage extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    ScreenUtil.init(context, designSize: Size(414, 896));
    return Scaffold(
      appBar: AppBar(
        title: Text("YFlutter Widgets Demo"),
      ),
      body: SafeArea(
        child: YCustomCard(
          sEdgeInsets: EdgeInsets.only(left: 16, top: 20, right: 16, bottom: 20),
          insideWidget: ListView(
            children: [
              /*
               * Customized Tab Bar.*/
              Center(
                child: MaterialButton(
                  child: Text('Customized Bottom Tab Bar'),
                  color: Colors.blue,
                  onPressed: () {
                    Application.router.navigateTo(context, Routes.yTabBarRoute);
                  },
                ),
              ),
              Divide(type: DivideType.Full),
              /*
              * Selectable Tags with Grid Display View.*/
              Center(
                child: MaterialButton(
                  child: Text('Selectable Tags Grid View'),
                  color: Colors.blue,
                  onPressed: () {
                    Application.router.navigateTo(context, Routes.yTagsGridRoute);
                  },
                ),
              ),
              Divide(type: DivideType.iOSTableDefault),
              /*
              * Customized Card View with free inside widgets.*/
              Center(
                child: MaterialButton(
                  child: Text('Customized Content CardView'),
                  color: Colors.blue,
                  onPressed: () {
                    Application.router.navigateTo(context, Routes.yCardRoute);
                  },
                ),
              ),
              Divide(type: DivideType.Center),
              Center(
                child: MaterialButton(
                  child: Text('Customized ListView'),
                  color: Colors.blue,
                  onPressed: () {
                    Application.router.navigateTo(context, Routes.yListRoute);
                  },
                ),
              ),
              YDashedLine(count: 20, dotSize: Size(5,5),),
            ],
          ),
        ),
      ),
    );
  }
}


